@@ -22,6 +22,20 @@ INSTANCE_SCHEMA = "instance"
 SOLUTION_SCHEMA = "solution"
 CONFIG_SCHEMA = "config"
 
+# why it stopped
+STATUS_NOT_SOLVED = 0
+STATUS_OPTIMAL = 1
+STATUS_INFEASIBLE = -1
+STATUS_UNBOUNDED = -2
+STATUS_UNDEFINED = -3
+STATUS_TIME_LIMIT = 2
+STATUS_MEMORY_LIMIT = 3
+STATUS_NODE_LIMIT = 4
+
+# is there a solution?
+SOLUTION_STATUS_INFEASIBLE = 0
+SOLUTION_STATUS_FEASIBLE = 2
+
 
 class InvalidUsage(Exception):
     status_code = 400
